datahike.pg.catalog.basis

Exact, bounded-size snapshots of stored SQL catalog inputs.

Exact capture is accelerated by checked runtime dependency tokens. Cached bases retain detached values only, bounded to eight entries and 32MiB of structural weight (not exact JVM heap). Strict schemas use attribute-index ranges; read schemas require an AEVT scan to discover undeclared catalog attributes. The latter also visits user data.

Exact, bounded-size snapshots of stored SQL catalog inputs.

Exact capture is accelerated by checked runtime dependency tokens. Cached
bases retain detached values only, bounded to eight entries and 32MiB of
structural weight (not exact JVM heap). Strict schemas use attribute-index
ranges; read schemas require an AEVT scan to discover undeclared catalog
attributes. The latter also visits user data.
raw docstring

*capture-cache*clj

Optional caller-owned IdentityHashMap, bound for one statement only. At most eight DB identities are retained. Mutable catalog captures bypass this cache; cross-statement reuse requires checked dependency tokens.

Optional caller-owned IdentityHashMap, bound for one statement only.
At most eight DB identities are retained. Mutable catalog captures bypass
this cache; cross-statement reuse requires checked dependency tokens.
sourceraw docstring

captureclj

(capture db)
(capture db options)

Detached exact schema/catalog comparison value; nil DB returns nil. See default-limits for structural bounds. Read schemas visit all AEVT datoms; strict schemas use catalog attribute ranges. Temporal/filter views are preserved. Eligible tracked snapshots share a bounded detached-basis cache. Mutable dates/arrays bypass both caches. Optional capture-cache reuses identical DB objects with equal limits/configuration/checked tokens and must be scoped by the caller to one statement.

Detached exact schema/catalog comparison value; nil DB returns nil.
See default-limits for structural bounds. Read schemas visit all AEVT
datoms; strict schemas use catalog attribute ranges. Temporal/filter views
are preserved. Eligible tracked snapshots share a bounded detached-basis
cache. Mutable dates/arrays bypass both caches. Optional *capture-cache*
reuses identical DB objects with equal limits/configuration/checked tokens
and must be scoped by the caller to one statement.
sourceraw docstring

catalog-attribute?clj

(catalog-attribute? attr)

Stored catalog namespaces, including future attributes in those namespaces. Sequence values are intentionally not catalog definitions. Ident datoms bind logical schema names to entity IDs, including schema entity ordering.

Stored catalog namespaces, including future attributes in those namespaces.
Sequence values are intentionally not catalog definitions. Ident datoms
bind logical schema names to entity IDs, including schema entity ordering.
sourceraw docstring

default-limitsclj

Structural accounting limits, not an exact JVM heap guarantee.

Structural accounting limits, not an exact JVM heap guarantee.
sourceraw docstring

freeze-projectionclj

(freeze-projection value)

Detach a metadata reader result under default structural limits. Token eligibility requires exclusively recognized immutable values; mutable values are detached but cannot certify subsequent token reuse.

Detach a metadata reader result under default structural limits.
Token eligibility requires exclusively recognized immutable values;
mutable values are detached but cannot certify subsequent token reuse.
sourceraw docstring

matches?clj

(matches? basis db)

Compare using a checked unchanged dependency token when eligible; otherwise compare exact detached metadata. Never trust hashes, transaction counters, server invalidation generations, or schema identity alone.

Compare using a checked unchanged dependency token when eligible; otherwise
compare exact detached metadata. Never trust hashes, transaction counters,
server invalidation generations, or schema identity alone.
sourceraw docstring

tracking-optionsclj

source

tracking-selectorclj

source

without-replayed-enum-markersclj

(without-replayed-enum-markers basis markers)

Normalize an expected replay basis for exact [entity label] marker adds intentionally omitted from the preceding transaction buffer. Never apply this to the writer's actual basis or to a semantic plan/cache key.

Normalize an expected replay basis for exact [entity label] marker adds
intentionally omitted from the preceding transaction buffer. Never apply
this to the writer's actual basis or to a semantic plan/cache key.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries